//
//  RAOpenQuickerMultiplePanel.m
//  OpenQuicker
//
//  Created by Quentin Carnicelli on 11/21/04.
//  Copyright 2004 Rogue Amoeba Software, LLC. All rights reserved.
//

#import "RAOpenQuickerMultiplePanel.h"


@implementation RAOpenQuickerMultiplePanel

static RAOpenQuickerMultiplePanel* _sharedPanel = nil;
static NSDictionary* _sharedTruncatingStringAttributes = nil;

+ (RAOpenQuickerMultiplePanel*)sharedPanel
{
	if( _sharedPanel == nil )
		_sharedPanel = [[self alloc] init];
	return _sharedPanel;
}

- (id)init
{
	return [self initWithWindowNibName: @"OpenQuickerMultiplePanel"];
}

- (void)windowDidLoad
{
	NSMutableParagraphStyle *style = [[NSParagraphStyle defaultParagraphStyle] mutableCopy];
	[style setLineBreakMode: NSLineBreakByTruncatingMiddle];
	_sharedTruncatingStringAttributes = [[NSDictionary alloc] initWithObjectsAndKeys:style, NSParagraphStyleAttributeName, nil];
	[style release];
	
	[[[mFileTable tableColumnWithIdentifier: @"filePath"] dataCell] setWraps: YES];
}

- (void)_rebuildModelForFiles: (NSArray*)files
{
	[mInputPaths release];
	mInputPaths = [files retain];
	[mFileTable reloadData];
	
	if( [mInputPaths count] )
		[mFileTable selectRowIndexes: [NSIndexSet indexSetWithIndex: 0] byExtendingSelection: NO];
	//[mFileTable selectAll: nil];
}

- (NSArray*)_selectedFiles
{
	NSIndexSet* selection = [mFileTable selectedRowIndexes];
	NSMutableArray* selectedFiles = [NSMutableArray arrayWithCapacity: [selection count]];
	int index;
		
	index = [selection firstIndex];
	while( index != NSNotFound )
	{
		[selectedFiles addObject: [mInputPaths objectAtIndex: index]];
		index = [selection indexGreaterThanIndex: index];
	}
	
	return selectedFiles;
}

- (NSArray*)runModalForFiles: (NSArray*)files
{
	int resultCode;
	
	if( [files count] <= 0 )
		return nil;
	else if( [files count] == 1 )
		return files;
	
	[[self window] center];

	[self _rebuildModelForFiles: files];
	resultCode = [[NSApplication sharedApplication] runModalForWindow: [self window]];
	[[self window] close];
	[self _rebuildModelForFiles: nil];

	return mOutputPaths;
}

- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
	return [mInputPaths count];
}

- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(int)row
{
	id obj = nil;
	NSString* path;
	
	path = [mInputPaths objectAtIndex: row];
	
	if( [[tableColumn identifier] isEqualToString: @"filePath"] )
	{
		obj = [[[NSAttributedString alloc] initWithString: path attributes: _sharedTruncatingStringAttributes] autorelease];
	}
	else if( [[tableColumn identifier] isEqualToString: @"icon16"] )
	{
		obj = [[NSWorkspace sharedWorkspace] iconForFileType: [path pathExtension]];
	}
	
	return obj;
}

- (IBAction)hitOK: (id)sender
{
	mOutputPaths = [[self _selectedFiles] retain];
	[[NSApplication sharedApplication] stopModalWithCode: NSOKButton];
}

- (IBAction)hitCancel: (id)sender
{
	mOutputPaths = nil;
	[[NSApplication sharedApplication] stopModalWithCode: NSCancelButton];
}

@end
