//
//  RAOpenQuickerPanel.m
//  OpenQuicker
//
//  Created by Quentin Carnicelli on 11/20/04.
//  Copyright 2004 Rogue Amoeba Software, LLC. All rights reserved.
//

#import "RAOpenQuickerPanel.h"

#import "RACompletingTextField.h"
#import "RASourceFileFinder.h"

@implementation RAOpenQuickerPanel

static RAOpenQuickerPanel* _sharedPanel = nil;

+ (RAOpenQuickerPanel*)sharedPanel
{
	if( _sharedPanel == nil )
		_sharedPanel = [[self alloc] init];
	return _sharedPanel;
}

- (id)init
{
	return [self initWithWindowNibName: @"OpenQuickerPanel"];
}

- (void)windowDidLoad
{
	[mFileField setCompletingMode: kRACompleteTextOnTab];
}

- (NSString*)runModalWithText: (NSString*)str fileFinder: (RASourceFileFinder*)finder
{
	int resultCode;

	//Load our window
	[[self window] center];

	//Load the starting text
	if( !str )
		str = @"";
	[mFileField setStringValue: str];
	
	mFileFinder = [finder retain];
	
	//Run it
	resultCode = [[NSApplication sharedApplication] runModalForWindow: [self window]];
	[[self window] close];

	[mFileFinder release];
	mFileFinder = nil;

	//Done
	if( resultCode == NSOKButton )
		str = [mFileField stringValue];
	else
		str = nil;
	
	return str;
}

- (NSArray *)textView:(NSTextView *)textView completions:(NSArray *)words forPartialWordRange:(NSRange)charRange indexOfSelectedItem:(int *)index
{
	NSString* searchFragment;
	
	if( charRange.length < 3 )
		return [NSArray array];
	
	searchFragment = [[[textView textStorage] string] substringWithRange:charRange];

	words = [mFileFinder wordCompletionsForFragment: searchFragment limit: -1];
		
	return words;
}


- (IBAction)hitOK: (id)sender
{
	[[NSApplication sharedApplication] stopModalWithCode: NSOKButton];
}

- (IBAction)hitCancel: (id)sender
{
	[[NSApplication sharedApplication] stopModalWithCode: NSCancelButton];
}

@end
